| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Waterfall.Loft
Contents
Description
Synopsis
- pointedLoftWithPrecision :: Double -> Maybe (V3 Double) -> [Path] -> Maybe (V3 Double) -> Solid
- pointedLoft :: Maybe (V3 Double) -> [Path] -> Maybe (V3 Double) -> Solid
- loft :: [Path] -> Solid
- tryPointedLoftWithPrecision :: Double -> Maybe (V3 Double) -> [Path] -> Maybe (V3 Double) -> Either WaterfallError Solid
- tryPointedLoft :: Maybe (V3 Double) -> [Path] -> Maybe (V3 Double) -> Either WaterfallError Solid
- tryLoft :: [Path] -> Either WaterfallError Solid
Documentation
pointedLoftWithPrecision Source #
Arguments
| :: Double | The loft precision, this should be a small value, e.g. |
| -> Maybe (V3 Double) | Optional start point for the loft |
| -> [Path] | Series of cross-sections that the loft will pass through |
| -> Maybe (V3 Double) | Optional end point for the loft |
| -> Solid |
like pointedLoft, but allows the user to set the precision used by the underlying algorithm
Arguments
| :: Maybe (V3 Double) | Optional start point for the loft |
| -> [Path] | Series of cross-sections that the loft will pass through |
| -> Maybe (V3 Double) | Optional end point for the loft |
| -> Solid |
Form a Loft which may terminate at defined points.
If the start or end points are set to Nothing then one end of the loft will be the terminal cross-section.
Otherwise, the loft will interpolate to that point.
Form a loft between a series of cross-sections.
Functions that return Errors
tryPointedLoftWithPrecision Source #
Arguments
| :: Double | The loft precision, this should be a small value, e.g. |
| -> Maybe (V3 Double) | Optional start point for the loft |
| -> [Path] | Series of cross-sections that the loft will pass through |
| -> Maybe (V3 Double) | Optional end point for the loft |
| -> Either WaterfallError Solid |
like pointedLoftWithPrecision, but returns an Either on error
Arguments
| :: Maybe (V3 Double) | Optional start point for the loft |
| -> [Path] | Series of cross-sections that the loft will pass through |
| -> Maybe (V3 Double) | Optional end point for the loft |
| -> Either WaterfallError Solid |
like pointedLoft, but returns an Either on error
Arguments
| :: [Path] | Series of cross-sections that the loft will pass through |
| -> Either WaterfallError Solid |
like pointedLoft, but returns an Either on error