waterfall-cad-0.6.3.1: Declarative CAD/Solid Modeling Library
Safe HaskellNone
LanguageHaskell2010

Waterfall.Revolution

Synopsis

Documentation

revolution :: Path2D -> Solid Source #

Construct a Solid of revolution from a Path2D.

The Path2D is rotated about the y axis, should have endpoints that lie on it ( \(x = 0\) ).

The resulting Solid is rotated such that the axis of revolution is the z axis.

tryRevolution :: Path2D -> Either WaterfallError Solid Source #

Version of revolution that returns an Error on failure.

Revolution can fail, for example, if the Path2D crosses the axis of revolution.