waterfall-cad-0.4.0.0: Declarative CAD/Solid Modeling Library
Safe HaskellNone
LanguageHaskell2010

Waterfall.TwoD.Internal.Path2D

Synopsis

Documentation

newtype Path2D Source #

A Path in 2D Space

Under the hood, this is represented by an OpenCascade Wire, constrained to the plane \(z=0\).

Please feel free to report a bug if you're able to construct a Path2D which does not lie on this plane (without using Internal functions).

Constructors

Path2D 

Fields

Instances

Instances details
Monoid Path2D Source # 
Instance details

Defined in Waterfall.TwoD.Internal.Path2D

Semigroup Path2D Source #

Joins Path2Ds, a <> b connects the end point of b to the start of b , if these points are not coincident, a line is created between them.

Attempts to combine paths in ways that generate a non manifold path will produce an error case that is not currently handled gracefully.

Instance details

Defined in Waterfall.TwoD.Internal.Path2D

Transformable2D Path2D Source # 
Instance details

Defined in Waterfall.TwoD.Transforms

AnyPath (V2 Double) Path2D Source # 
Instance details

Defined in Waterfall.Path.Common