waterfall-cad-0.6.3.1: Declarative CAD/Solid Modeling Library
Safe HaskellNone
LanguageHaskell2010

Waterfall.TwoD.Text

Synopsis

Documentation

text :: Font -> String -> Shape Source #

Render text, using a given font

fontFromPath :: FilePath -> Double -> IO Font Source #

Create a font from a filepath and a font size

fontFromSystem :: String -> FontAspect -> Double -> IO Font Source #

Create a font from a system font name, aspect, and size