| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Waterfall.TwoD.Internal.Path2D
Documentation
A Path in 2D Space
Under the hood, this is represented by an OpenCascade Wire, constrained to the plane \(z=0\).
Please feel free to report a bug if you're able to construct a Path2D
which does not lie on this plane (without using Internal functions).
Instances
| Monoid Path2D Source # | |
| Semigroup Path2D Source # | Joins Attempts to combine paths in ways that generate a non manifold path will produce an error case that is not currently handled gracefully. |
| Transformable2D Path2D Source # | |
| AnyPath (V2 Double) Path2D Source # | |